@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The Balloon Learning Environment Authors.
+# Copyright 2022 The Balloon Learning Environment Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,7 +20,7 @@ This provides the RL layer on top of the simulator.
 
 import math
 import time
-from typing import Any, Callable, Mapping, Optional, Text, Tuple, Union
+from typing import Any, Callable, Mapping, Optional, Text, Tuple, Union, Dict
 
 from balloon_learning_environment.env import balloon_arena
 from balloon_learning_environment.env import features
@@ -33,7 +33,6 @@ from balloon_learning_environment.env.balloon import standard_atmosphere
 from balloon_learning_environment.env.rendering import renderer as randerer_lib
 from balloon_learning_environment.utils import transforms
 from balloon_learning_environment.utils import units
-from flax.metrics import tensorboard
 import gin
 import gym
 import jax
@@ -141,7 +140,6 @@ class BalloonEnv(gym.Env):
     self._reward_fn = reward_function
     self._feature_constructor_factory = feature_constructor_factory
     self._global_iteration = 0
-    self.summary_writer = None
 
     if arena is None:
       self.arena = balloon_arena.BalloonArena(self._feature_constructor_factory,
@@ -154,8 +152,7 @@ class BalloonEnv(gym.Env):
       self.metadata = {'render.modes': self._renderer.render_modes}
 
     # Use time in microseconds if a seed is not supplied.
-    self.seed(seed if seed is not None else int(time.time() * 1e6))
-    self.reset()
+    self.reset(seed=seed if seed is not None else int(time.time() * 1e6))
 
   def step(self,
            action: int) -> Tuple[np.ndarray, float, bool, Mapping[str, Any]]:
@@ -181,29 +178,38 @@ class BalloonEnv(gym.Env):
     reward = self._reward_fn(simulator_state)
 
     # Prepare is_terminal
-    balloon_state = simulator_state.balloon_state
-    out_of_power = balloon_state.status == balloon.BalloonStatus.OUT_OF_POWER
-    envelope_burst = (
-        balloon_state.status == balloon.BalloonStatus.BURST)
-    zeropressure = (
-        balloon_state.status == balloon.BalloonStatus.ZEROPRESSURE)
-    is_terminal = out_of_power or envelope_burst or zeropressure
+    info = self._get_info(simulator_state.balloon_state)
+    is_terminal = (
+        info['out_of_power']
+        or info['envelope_burst']
+        or info['zeropressure']
+    )
 
-    self._gather_summaries(action)
     self._global_iteration += 1
 
-    return observation, reward, is_terminal, {
-        'out_of_power': out_of_power,
-        'envelope_burst': envelope_burst,
-        'zeropressure': zeropressure,
-        'time_elapsed': balloon_state.time_elapsed}
+    return observation, reward, is_terminal, info
 
-  def reset(self) -> np.ndarray:
+  def reset(
+      self,
+      *,
+      seed: Optional[int] = None,
+      return_info: bool = False
+  ) -> Union[np.ndarray, Tuple[np.ndarray, Mapping[str, Any]]]:
     """Resets the environment.
 
+    Args:
+      seed: Seed to re-seed environment on reset.
+      return_info: return info dictionary with initial observation.
+
     Returns:
-      The initial observation.
+      If `return_info` is True:
+        A tuple consisting of initial_observation and the info dictionary.
+      Otherwise:
+        The initial observation.
     """
+    if seed is not None:
+      self.seed(seed)
+
     self._rng, arena_rng = jax.random.split(self._rng)
     observation = self.arena.reset(arena_rng)
 
@@ -211,17 +217,22 @@ class BalloonEnv(gym.Env):
       self._renderer.reset()
       self._renderer.step(self.arena.get_simulator_state())
 
-    return observation
+    if return_info:
+      simulator_state = self.get_simulator_state()
+      info = self._get_info(simulator_state.balloon_state)
+
+      return observation, info
+    else:
+      return observation
 
   def render(self, mode: str = 'human') -> Union[None, np.ndarray, Text]:
     """Renders a frame.
 
     Args:
-      mode: One of `human`, `rgb_array`, `ansi`, or `tensorboard`. `human`
+      mode: One of `human`, `rgb_array`, or `ansi`. `human`
         corresponds to rendering directly to the screen. `rgb_array` renders to
         a numpy array and returns it. `ansi` renders to a string or StringIO
-        object. `tensorboard` renders the images on tensorboard (if that
-        collector is active).
+        object.
 
     Returns:
       None, a numpy array of rgb data, or a Text object, depending on the mode.
@@ -233,10 +244,6 @@ class BalloonEnv(gym.Env):
     if self._renderer is None:
       return None
 
-    if mode == 'tensorboard':
-      return self._renderer.render(
-          mode, self.summary_writer, self._global_iteration)
-
     return self._renderer.render(mode)
 
   def close(self) -> None:
@@ -270,8 +277,20 @@ class BalloonEnv(gym.Env):
     """Gets the simulator state."""
     return self.arena.get_simulator_state()
 
+  def _get_info(self, balloon_state: balloon.BalloonState) -> Dict[str, Any]:
+    out_of_power = balloon_state.status == balloon.BalloonStatus.OUT_OF_POWER
+    envelope_burst = balloon_state.status == balloon.BalloonStatus.BURST
+    zeropressure = balloon_state.status == balloon.BalloonStatus.ZEROPRESSURE
+
+    return {
+        'out_of_power': out_of_power,
+        'envelope_burst': envelope_burst,
+        'zeropressure': zeropressure,
+        'time_elapsed': balloon_state.time_elapsed
+    }
+
   def __str__(self) -> str:
-    return 'SleewpalkEnv'
+    return 'BalloonEnv'
 
   def __enter__(self) -> gym.Env:
     return self
@@ -279,25 +298,3 @@ class BalloonEnv(gym.Env):
   def __exit__(self, *args: Any) -> bool:
     self.close()
     return False  # Reraise any exceptions
-
-  def set_summary_writer(
-      self, summary_writer: Optional[tensorboard.SummaryWriter]) -> None:
-    """Sets a summary writer for logging information to tensorboard."""
-    self.summary_writer = summary_writer
-
-  # TODO(psc): This shouldn't be done here. Modify this so it is passed back to
-  # the dispatcher (which passes it to the collectors).
-  def _gather_summaries(self, action: int):
-    """If summary_writer is available, gather summaries from BalloonArena."""
-    if self.summary_writer is None:
-      return
-
-    self.summary_writer.scalar('Balloon/Actions', action,
-                               self._global_iteration)
-    self.arena.get_summaries(self.summary_writer, self._global_iteration)
-    self.render(mode='tensorboard')
-
-
-gym.register(
-    id='BalloonLearningEnvironment-v0',
-    entry_point='balloon_learning_environment.env.balloon_env:BalloonEnv')
